Django Admin Tools Stats Documentation! — django-admin-charts 0.25.0 documentation

# Django Admin Tools Stats Documentation!

Release:

  0.25.0

Date:

  Dec 28, 2021

Keywords:

  django, python, plot, graph, nvd3, d3, dashboard

Author:

  Arezqui Belaid, Petr Dlouhý

Description:

  Django-admin-tools-stats is a Django admin module that allow you to create easily charts on your dashboard based on specific models and criterias.

Contents:

- Introduction
- Requirements
- Installation
  - Basic setup for `django-admin`
- Special configurations
  - Update from `django-admin-tools-stats`
  - Installation of javascript libraries with `django-bower`
  - Usage with `django-admin-tools`
  - Usage on DB that doesn’t support JSONFields
- Running demo
- Development
  - Dependencies
  - Contributing
  - Debugging charts
  - Documentation
  - License
- Developer Documentation
  - Prerequisites
  - Objects Description
  - Django-admin-tools-stats Modules
  - Test Case Descriptions

# Indices and tables

- Index

- Module Index

- Search Page